==> vite_1.1.orig.tar.gz: vite-1.1/src/trace/StateChange.hpp <==
/*
** This file is part of the ViTE project.
**
** This software is governed by the CeCILL-A license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-A license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-A license and that you accept its terms.
**
**
** ViTE developers are (for version 0.* to 1.0):
**
**        - COULOMB Kevin
**        - FAVERGE Mathieu
**        - JAZEIX Johnny
**        - LAGRASSE Olivier
**        - MARCOUEILLE Jule
**        - NOISETTE Pascal
**        - REDONDY Arthur
**        - VUCHENER Clément 
**
*/
#ifndef STATECHANGE_HPP
#define STATECHANGE_HPP

/*!
 * \class StateChange
 */
class StateChange {
private:
    Date _time;
    State *_left, *_right;
    
public:
    StateChange(Date time);
    StateChange(Date time, State *left, State *right=0);
    
    void set_right_state(State *right);
    Date get_time() const;
    State *get_left_state();
    State *get_right_state();
    const State *get_left_state() const;
    const State *get_right_state() const;
    ~StateChange();
};

#endif

==> vite_1.2.orig.tar.gz: vite-1.2/src/trace/StateChange.hpp <==
/*
** This file is part of the ViTE project.
**
** This software is governed by the CeCILL-A license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-A license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-A license and that you accept its terms.
**
**
** ViTE developers are (for version 0.* to 1.0):
**
**        - COULOMB Kevin
**        - FAVERGE Mathieu
**        - JAZEIX Johnny
**        - LAGRASSE Olivier
**        - MARCOUEILLE Jule
**        - NOISETTE Pascal
**        - REDONDY Arthur
**        - VUCHENER Clément 
**
*/
#ifndef STATECHANGE_HPP
#define STATECHANGE_HPP

/*!
 * \class StateChange
 */
template <typename E> class BinaryTree;

class StateChange {
public:
    typedef std::list<StateChange *>                 Vector;
    typedef std::list<StateChange *>::const_iterator VectorIt;
    typedef BinaryTree<StateChange>                  Tree;

private:
    Date _time;
    State *_left, *_right;
    
public:
    StateChange(Date time);
    StateChange(Date time, State *left, State *right=0);
    
    void set_right_state(State *right);
    Date get_time() const;
    State *get_left_state();
    State *get_right_state();
    const State *get_left_state() const;
    const State *get_right_state() const;
    ~StateChange();
};

#endif
